==> django-sql-explorer-0.7.tar.gz: django-sql-explorer-0.7/explorer/static/explorer/explorer.js <==
var csrf_token = $.cookie('csrftoken');
$.ajaxSetup({
    beforeSend: function(xhr) {
        xhr.setRequestHeader("X-CSRFToken", csrf_token);
    }
});

function ExplorerEditor(queryId, dataUrl) {
    this.queryId = queryId;
    this.dataUrl = dataUrl;
    this.$table = $('#preview');
    this.$rows = $('#rows');
    this.$form = $("form");
    this.$paramFields = this.$form.find(".param");

    this.$submit = $("#save_button");
    if (!this.$submit.length) { this.$submit = $("#refresh_button"); }

    this.editor = CodeMirror.fromTextArea(document.getElementById('id_sql'), {
        mode: "text/x-sql",
        lineNumbers: 't',
        autofocus: true,
        extraKeys: {
            "Ctrl-Enter": function() { this.doCodeMirrorSubmit(); }.bind(this),
            "Cmd-Enter": function() { this.doCodeMirrorSubmit(); }.bind(this)
        }
    });
    this.bind();
}

ExplorerEditor.prototype.getParams = function() {
    var o = false;
    if(this.$paramFields.length) {
        o = {};
        this.$paramFields.each(function() {
            o[this.id.replace("_param", "")] = $(this).val();
        });
    }
    return o;
};

ExplorerEditor.prototype.doCodeMirrorSubmit = function() {
    // Captures the cmd+enter keystroke and figures out which button to trigger.
    this.$submit.click();
};

ExplorerEditor.prototype.updateQueryString = function(key, value, url) {
    // http://stackoverflow.com/a/11654596/221390
    if (!url) url = window.location.href;
    var re = new RegExp("([?&])" + key + "=.*?(&|#|$)(.*)", "gi");

    if (re.test(url)) {
        if (typeof value !== 'undefined' && value !== null)
            return url.replace(re, '$1' + key + "=" + value + '$2$3');
        else {
            var hash = url.split('#');
            url = hash[0].replace(re, '$1$3').replace(/(&|\?)$/, '');
            if (typeof hash[1] !== 'undefined' && hash[1] !== null)
                url += '#' + hash[1];
            return url;
        }
    }
    else {
        if (typeof value !== 'undefined' && value !== null) {
            var separator = url.indexOf('?') !== -1 ? '&' : '?',
                hash = url.split('#');
            url = hash[0] + separator + key + '=' + value;
            if (typeof hash[1] !== 'undefined' && hash[1] !== null)
                url += '#' + hash[1];
            return url;
        }
        else
            return url;
    }
};

ExplorerEditor.prototype.formatSql = function() {
    $.post('../format/', {sql: this.editor.getValue() }, function(data) {
        this.editor.setValue(data.formatted);
    }.bind(this));
};

ExplorerEditor.prototype.showRows = function() {
    var rows = this.$rows.val(),
        $form = $("#editor");
    $form.attr('action', this.updateQueryString("rows", rows, window.location.href));
    $form.submit();
};

ExplorerEditor.prototype.bind = function() {
    $("#show_schema_button").click(function() {
        $("#schema_frame").attr('src', '../schema/');
        $("#query_area").addClass("col-md-9");
        var schema$ = $("#schema");
        schema$.addClass("col-md-3");
        schema$.show();
        $(this).hide();
        $("#hide_schema_button").show();
        return false;
    });

    $("#hide_schema_button").click(function() {
        $("#query_area").removeClass("col-md-9");
        var schema$ = $("#schema");
        schema$.removeClass("col-md-3");
        schema$.hide();
        $(this).hide();
        $("#show_schema_button").show();
        return false;
    });

    $("#format_button").click(function(e) {
        e.preventDefault();
        this.formatSql();
    }.bind(this));

    $('a[data-toggle="tab"]').on('shown.bs.tab', function (e) {
        if(e.target.hash == "#chart") {
            var pageController = new PageController();
            pageController.setupPage({dataUrl: this.dataUrl})
        }
    }.bind(this));

    $("#save_button").click(function() {
        var params = this.getParams(this);
        if(params) {
            this.$form.attr('action', '../' + this.queryId + '/?params=' + JSON.stringify(params));
        }
    }.bind(this));

    $("#refresh_button").click(function(e) {
        e.preventDefault();
        var params = this.getParams();
        if(params) {
            window.location.href = '../' + this.queryId + '/?params=' + JSON.stringify(params);
        } else {
            window.location.href = '../' + this.queryId + '/';
        }
    }.bind(this));

    $("#refresh_play_button, #playground_button").click(function() {
        this.$form.attr('action', '../play/');
    }.bind(this));

    $("#download_play_button").click(function() {
        this.$form.attr('action', '../csv');
    }.bind(this));

    $(".download_button").click(function(e) {
        e.preventDefault();
        var dl_link = 'download';
        var params = this.getParams(this);
        if(params) { dl_link = dl_link + '?params=' + JSON.stringify(params); }
        window.open(dl_link, '_blank');
    }.bind(this));

    $("#create_button").click(function() {
        this.$form.attr('action', '../new/');
    }.bind(this));

    this.$table.floatThead({
        scrollContainer: function() {
                            return this.$table.closest('.overflow-wrapper');
                        }.bind(this)
    });

    this.$rows.change(function() { this.showRows(); }.bind(this));
    this.$rows.keyup(function(event){
        if(event.keyCode == 13){ this.showRows(); }
    }.bind(this));
};

==> django-sql-explorer-0.8.tar.gz: django-sql-explorer-0.8/explorer/static/explorer/explorer.js <==
var csrf_token = $.cookie('csrftoken');
$.ajaxSetup({
    beforeSend: function(xhr) {
        xhr.setRequestHeader("X-CSRFToken", csrf_token);
    }
});

function ExplorerEditor(queryId, dataUrl) {
    this.queryId = queryId;
    this.dataUrl = dataUrl;
    this.$table = $('#preview');
    this.$rows = $('#rows');
    this.$form = $("form");
    this.$snapshotField = $("#id_snapshot");
    this.$paramFields = this.$form.find(".param");

    this.$submit = $("#refresh_play_button, #save_button");
    if (!this.$submit.length) { this.$submit = $("#refresh_button"); }

    this.editor = CodeMirror.fromTextArea(document.getElementById('id_sql'), {
        mode: "text/x-sql",
        lineNumbers: 't',
        autofocus: true,
        extraKeys: {
            "Ctrl-Enter": function() { this.doCodeMirrorSubmit(); }.bind(this),
            "Cmd-Enter": function() { this.doCodeMirrorSubmit(); }.bind(this)
        }
    });
    this.bind();
}

ExplorerEditor.prototype.getParams = function() {
    var o = false;
    if(this.$paramFields.length) {
        o = {};
        this.$paramFields.each(function() {
            o[this.id.replace("_param", "")] = $(this).val();
        });
    }
    return o;
};

ExplorerEditor.prototype.doCodeMirrorSubmit = function() {
    // Captures the cmd+enter keystroke and figures out which button to trigger.
    this.$submit.click();
};

ExplorerEditor.prototype.updateQueryString = function(key, value, url) {
    // http://stackoverflow.com/a/11654596/221390
    if (!url) url = window.location.href;
    var re = new RegExp("([?&])" + key + "=.*?(&|#|$)(.*)", "gi");

    if (re.test(url)) {
        if (typeof value !== 'undefined' && value !== null)
            return url.replace(re, '$1' + key + "=" + value + '$2$3');
        else {
            var hash = url.split('#');
            url = hash[0].replace(re, '$1$3').replace(/(&|\?)$/, '');
            if (typeof hash[1] !== 'undefined' && hash[1] !== null)
                url += '#' + hash[1];
            return url;
        }
    }
    else {
        if (typeof value !== 'undefined' && value !== null) {
            var separator = url.indexOf('?') !== -1 ? '&' : '?',
                hash = url.split('#');
            url = hash[0] + separator + key + '=' + value;
            if (typeof hash[1] !== 'undefined' && hash[1] !== null)
                url += '#' + hash[1];
            return url;
        }
        else
            return url;
    }
};

ExplorerEditor.prototype.formatSql = function() {
    $.post('../format/', {sql: this.editor.getValue() }, function(data) {
        this.editor.setValue(data.formatted);
    }.bind(this));
};

ExplorerEditor.prototype.showRows = function() {
    var rows = this.$rows.val(),
        $form = $("#editor");
    $form.attr('action', this.updateQueryString("rows", rows, window.location.href));
    $form.submit();
};

ExplorerEditor.prototype.bind = function() {
    $("#show_schema_button").click(function() {
        $("#schema_frame").attr('src', '../schema/');
        $("#query_area").addClass("col-md-9");
        var schema$ = $("#schema");
        schema$.addClass("col-md-3");
        schema$.show();
        $(this).hide();
        $("#hide_schema_button").show();
        return false;
    });

    $("#hide_schema_button").click(function() {
        $("#query_area").removeClass("col-md-9");
        var schema$ = $("#schema");
        schema$.removeClass("col-md-3");
        schema$.hide();
        $(this).hide();
        $("#show_schema_button").show();
        return false;
    });

    $("#format_button").click(function(e) {
        e.preventDefault();
        this.formatSql();
    }.bind(this));

    $('a[data-toggle="tab"]').on('shown.bs.tab', function (e) {
        if(e.target.hash == "#chart") {
            var pageController = new PageController();
            pageController.setupPage({dataUrl: this.dataUrl})
        }
    }.bind(this));

    $("#save_button").click(function() {
        var params = this.getParams(this);
        if(params) {
            this.$form.attr('action', '../' + this.queryId + '/?params=' + JSON.stringify(params));
        }
        this.$snapshotField.hide();
        this.$form.append(this.$snapshotField);
    }.bind(this));

    $("#refresh_button").click(function(e) {
        e.preventDefault();
        var params = this.getParams();
        if(params) {
            window.location.href = '../' + this.queryId + '/?params=' + JSON.stringify(params);
        } else {
            window.location.href = '../' + this.queryId + '/';
        }
    }.bind(this));

    $("#refresh_play_button").click(function() {
        this.$form.attr('action', '../play/');
    }.bind(this));

    $("#playground_button").click(function() {
        this.$form.prepend("<input type=hidden name=show value='' />");
        this.$form.attr('action', '../play/');
    }.bind(this));

    $("#download_play_button").click(function() {
        this.$form.attr('action', '../csv');
    }.bind(this));

    $(".download_button").click(function(e) {
        e.preventDefault();
        var dl_link = 'download';
        var params = this.getParams(this);
        if(params) { dl_link = dl_link + '?params=' + JSON.stringify(params); }
        window.open(dl_link, '_blank');
    }.bind(this));

    $("#create_button").click(function() {
        this.$form.attr('action', '../new/');
    }.bind(this));

    $(".stats-expand").click(function(e) {
        e.preventDefault();
        $(".stats-expand").hide();
        $(".stats-wrapper").show();
    });

    this.$table.floatThead({
        scrollContainer: function() {
                            return this.$table.closest('.overflow-wrapper');
                        }.bind(this)
    });

    this.$rows.change(function() { this.showRows(); }.bind(this));
    this.$rows.keyup(function(event){
        if(event.keyCode == 13){ this.showRows(); }
    }.bind(this));
};
